use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
ARRAYn
Anno
AnnoCPAN
Branno
DROLSKY
DROLSKY's
Dave
EXPR
Filmer
Inkster
Jens
KEYFUNC
LSU
List
MULTICALL
McCauley
Muey
Parseval
PayPal
Purkis
Rabbitson
Rehsack
Rezic
Rolsky
Rolsky's
Roode
Siegel
Signes
Slaven
SomeUtils
Summersault
TODO
Tassilo
Tatham
Thegler
XS
autarch
bsearchidx
de
drolsky
firstidx
firstres
firstval
glitchy
lastidx
lastres
lastval
lib
listify
minmax
natatime
notall
onlyidx
onlyres
onlyval
refactor
rehsackATcpan
thusly
uniq
von
